@@ -1,21 +1,24 @@
 package Quantum::Superpositions::Lazy;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use v5.28;
 use warnings;
 use feature qw(signatures);
 no warnings qw(experimental::signatures);
 
+use Carp qw(croak);
 use Quantum::Superpositions::Lazy::Superposition;
 use Quantum::Superpositions::Lazy::Operation::Logical;
-use Exporter;
+use Quantum::Superpositions::Lazy::Util qw(is_collapsible);
+use Exporter qw(import);
 
 our @EXPORT = qw(
 	superpos
 );
 
 our @EXPORT_OK = qw(
+	collapse
 	any_state
 	every_state
 	one_state
@@ -27,16 +30,6 @@ our $global_reducer_type = "any";
 our $global_compare_bool = 1;
 our $global_sourced_calculations = 0;
 
-sub import
-{
-	for my $exported (@EXPORT) {
-		push @_, $exported
-			unless grep { $_ eq $exported } @_;
-	}
-
-	goto &Exporter::import;
-}
-
 sub run_sub_as ($sub, %env)
 {
 	local $global_reducer_type = $env{reducer_type} // $global_reducer_type;
@@ -61,6 +54,15 @@ sub superpos (@positions)
 	);
 }
 
+sub collapse (@superpositions)
+{
+	return map {
+		croak "Element not collapsible"
+			unless is_collapsible($_);
+		$_->collapse;
+	} @superpositions;
+}
+
 sub any_state : prototype(&) ($sub)
 {
 	return run_sub_as $sub, reducer_type => "any";
@@ -181,7 +183,7 @@ Refer to L<Quantum::Superpositions::Lazy::Manual> for a quick tutorial.
 	superpos(@data)
 	superpos([@data])
 
-Always exported. Feeds its arguments to the
+Exported by default. Feeds its arguments to the
 L<Quantum::Superpositions::Lazy::Superposition> constructor. If the only argument is an
 array reference, it is passed as-is into the constructor, resulting with a
 state for every array ref element. Otherwise creates a reference out of the
@@ -199,6 +201,12 @@ arguments and passes them instead.
 	# Any data is OK
 	superpos(qw(dont eat the fish));
 
+=head2 collapse
+
+	collapse(@data)
+
+Takes a list of argument that each must be an instance of I<Quantum::Superpositions::Lazy::Role::Collapsible>. Returns the list of results of calling a L<Quantum::Superpositions::Lazy::Superposition/collapse> method on each of them.
+
 =head2 any_state
 
 =head2 every_state
